#
# spec file for package soapy-uhd
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soapy_modver 0.8
%define soapy_modname soapysdr%{soapy_modver}-module-uhd

Name:           soapy-uhd
Version:        0.4.1
Release:        2.15
Summary:        Soapy SDR plugins for UHD supported SDR devices
License:        GPL-3.0-only
Group:          Hardware/Other
URL:            https://github.com/pothosware/SoapyUHD/wiki
#Git-Clone:     https://github.com/pothosware/SoapyUHD.git
Source:         https://github.com/pothosware/SoapyUHD/archive/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(SoapySDR)
BuildRequires:  pkgconfig(uhd)
%if 0%{?suse_version} > 1500
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%endif

%description
Soapy UHD - Soapy SDR devices for UHD.
A UHD module that supports Soapy devices within the UHD API.

%package -n %{soapy_modname}
Summary:        Soapy SDR plugins for UHD supported SDR devices
Group:          System/Libraries
# soapysdr0.7-module-uhd needs to be force dropped
Conflicts:      soapysdr0.7-module-uhd
# Add 'Provides/Obsoletes' entries for future updates
Provides:       soapy-uhd-module = %{soapy_modver}
Obsoletes:      soapy-uhd-module < %{soapy_modver}

%description -n %{soapy_modname}
Soapy UHD - Soapy SDR devices for UHD.
A UHD module that supports Soapy devices within the UHD API.

%prep
%setup -q -n SoapyUHD-%{name}-%{version}

%build
%cmake
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install

%files -n %{soapy_modname}
%license COPYING
%doc Changelog.txt README.md
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libuhdSupport.so
%dir %{_libdir}/uhd
%dir %{_libdir}/uhd/modules
%{_libdir}/uhd/modules/libsoapySupport.so

%changelog
* Tue Oct 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix installation conflicts with soapysdr0.7-module-uhd.
- Add Provides/Obsoletes to avoid issues with future updates.
* Sat Jul 10 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- SoapySDR version bumped to 0.8
* Mon Sep 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.1
  * Fix for UHD_VERSION define and 4.0 release compilation
- Drop not longer needed patch:
  * 0001-Fix-for-UHD_VERSION-check-for-4.0.patch (fixed by upstream)
* Fri Sep 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0
  * Support for compilation with UHD 4.0 release
- Add patch:
  * 0001-Fix-for-UHD_VERSION-check-for-4.0.patch
* Wed Jun 26 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.3.6
  * Support tuning on boards without a CORDIC in the DSP by
    registering a dummy second tuning element
* Sun Mar 24 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fix build with Boost 1.69
* Thu Dec 13 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.3.5
  * Create fake channels if the number of TX and RX channels
    are not equal to fix segmentation faults in UHD based tools
* Sat Nov 10 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update soapy-module version 0.6 -> 0.7
* Fri Jun  8 2018 wk@ire.pw.edu.pl
- Update to version 0.3.4
  * Optional check for dsp freq range in property tree
  * Tx de/activateStream() return 0 for NOP, not an error
  * Support timestamp for deactivateStream() stream command
  * Conditional support for new logging API (replaces msg.hpp)
  * Tx stream activation hooks based on start and end of burst
* Fri May  5 2017 mardnh@gmx.de
- Update to version 0.3.3
  * Results for frequency component with no tune result
  * Fix arg for set_rx_subdev_spec() in UHDSoapyDevice
  * Support getBandwidthRange()/getSampleRateRange()
  * UHDSoapyDevice supports zero length buffer send()
  * Implement timestamp interpolation for uhd rx streams
  * Added label convention to soapy uhd discovery routine
  * Support for optional gain range step in type conversions
* Wed Apr 19 2017 mardnh@gmx.de
- renamed packages according the debian package name from upstream
* Fri Apr 14 2017 mardnh@gmx.de
- Update to version 0.3.2 (tagged release)
- renamed package from SoapyUHD to soapy-uhd
- specfile cleanup
* Tue Jan  3 2017 mardnh@gmx.de
- Update to version 0.3.1.git1483171554.d624ef0:
  * support property tree API changes
  * support setHardwareTime(CMD), deprecated setCommandTime()
  * separate project and debian changelogs
  * changelog notes for property tree API support
  * changelog entry for 0.3.1
  * debian: update for soapySDR module ABI format
  * debian: fixed rules executable bit
  * Corrections for license and copyright text
  * changelog entry for copyright/license commit
  * Symlinks to workaround uhd 3.10 multi-arch bug
  * Added corrections hooks for soapy devices in uhd
  * Added tx/rx_subdev device argument for uhd device
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 0.2.0.git1448007406.db55e3a:
  + uhd: update for SoapySDR v0.4 arg info calls
  + travis: install uhd from drivers ppa
  + travis: fix uhd install command (no recommends)
  + travis: unit check that driver loads
* Sun Oct 11 2015 mardnh@gmx.de
- initial package
